@@ -189,7 +189,7 @@ handle_share_surface_damage(void *data, struct ivi_share_surface *share_surface,
 
         window->share_buffer.eglimage =
             pfEglCreateImageKHR(display->egl.egldisplay, EGL_NO_CONTEXT,
-                                EGL_DRM_BUFFER_MESA, (EGLClientBuffer)name,
+                                EGL_DRM_BUFFER_MESA, (EGLClientBuffer) (intptr_t)name,
                                 img_attribs);
         if (window->share_buffer.eglimage == NULL) {
             fprintf(stderr, "failed to create EGLImageKHR: 0x%04x\n",
@@ -633,6 +633,9 @@ destroy_window(struct window *window)
     if (window->share_surface)
         ivi_share_surface_destroy(window->share_surface);
 
+    if (window->ivi_surface)
+        ivi_surface_destroy(window->ivi_surface);
+
     if (window->surface)
         wl_surface_destroy(window->surface);
 
@@ -649,6 +652,9 @@ destroy_display(struct display *display)
     if (display->ivi_application)
         ivi_application_destroy(display->ivi_application);
 
+    if (display->seat)
+        wl_seat_destroy(display->seat);
+
     if (display->compositor)
         wl_compositor_destroy(display->compositor);
 
