@@ -150,16 +150,17 @@ share_surface_redirect_touch_down(struct wl_client *client,
             uint32_t new_serial =
                 wl_display_next_serial(client_link->parent->shell_ext->wc->wl_display);
             wl_touch_send_down(target_resource, new_serial, time, surface_resource, id, x, y);
+
+            redirect_target = malloc(sizeof *redirect_target);
+            redirect_target->client = client;
+            redirect_target->resource = resource;
+            redirect_target->target_resource = target_resource;
+            redirect_target->id = id;
+            wl_list_insert(&client_link->parent->shell_ext->list_redirect_target, &redirect_target->link);
+
             break;
         }
     }
-
-    redirect_target = malloc(sizeof *redirect_target);
-    redirect_target->client = client;
-    redirect_target->resource = resource;
-    redirect_target->target_resource = target_resource;
-    redirect_target->id = id;
-    wl_list_insert(&client_link->parent->shell_ext->list_redirect_target, &redirect_target->link);
 }
 
 static void
@@ -521,7 +522,7 @@ static struct ivi_share_interface g_share_implementation = {
 
 static struct ivi_shell_share_ext*
 init_ivi_shell_share_ext(struct weston_compositor *wc,
-                         const struct ivi_controller_interface *controller_interface,
+                         const struct ivi_layout_interface *controller_interface,
                          struct ivi_shell_share_ext *shell_ext)
 {
     shell_ext = calloc(1, sizeof(*shell_ext));
@@ -693,7 +694,7 @@ add_weston_surf_data(struct wl_listener *listener, void *data)
 
 int32_t
 setup_buffer_sharing(struct weston_compositor *wc,
-                     const struct ivi_controller_interface *interface)
+                     const struct ivi_layout_interface *interface)
 {
     if (NULL == wc || NULL == interface) {
         weston_log("Can not execute buffer sharing.\n");
